@@ -13,6 +13,7 @@ OVN_NB_REMOTE=${OVN_NB_REMOTE:-$OVN_PROTO:$SERVICE_HOST:6641}
 
 function _configure_provider_driver {
     iniset ${OCTAVIA_CONF} api_settings enabled_provider_drivers ${OCTAVIA_PROVIDER_DRIVERS}
+    iniset ${OCTAVIA_CONF} driver_agent enabled_provider_agents ${OCTAVIA_PROVIDER_AGENTS}
     iniset ${OCTAVIA_CONF} ovn ovn_nb_connection "$OVN_NB_REMOTE"
 
     if is_service_enabled tls-proxy; then
@@ -24,7 +25,9 @@ function _configure_provider_driver {
 }
 
 function is_ovn_enabled {
-    [[ $NEUTRON_AGENT == "ovn" ]] && return 0
+    if [[ $NEUTRON_AGENT == "ovn" || $Q_AGENT == "ovn" ]]; then
+        return 0
+    fi
     return 1
 }
 
