@@ -38,13 +38,14 @@ LB_EXT_IDS_VIP_KEY = 'neutron:vip'
 LB_EXT_IDS_VIP_FIP_KEY = 'neutron:vip_fip'
 LB_EXT_IDS_VIP_PORT_ID_KEY = 'neutron:vip_port_id'
 
+PORT_FORWARDING_PLUGIN = 'port_forwarding_plugin'
+
 # Auth sections
 SERVICE_AUTH = 'service_auth'
 
 # Request type constants
 REQ_TYPE_LB_CREATE = 'lb_create'
 REQ_TYPE_LB_DELETE = 'lb_delete'
-REQ_TYPE_LB_FAILOVER = 'lb_failover'
 REQ_TYPE_LB_UPDATE = 'lb_update'
 REQ_TYPE_LISTENER_CREATE = 'listener_create'
 REQ_TYPE_LISTENER_DELETE = 'listener_delete'
@@ -71,9 +72,10 @@ REQ_INFO_MEMBER_DELETED = 'member_deleted'
 # Disabled resources have a ':D' at the end
 DISABLED_RESOURCE_SUFFIX = 'D'
 
-# This driver only supports TCP and UDP, with a single LB algorithm
+# This driver only supports TCP, UDP and SCTP, with a single LB algorithm
 OVN_NATIVE_LB_PROTOCOLS = [constants.PROTOCOL_TCP,
-                           constants.PROTOCOL_UDP, ]
+                           constants.PROTOCOL_UDP,
+                           constants.PROTOCOL_SCTP, ]
 OVN_NATIVE_LB_ALGORITHMS = [constants.LB_ALGORITHM_SOURCE_IP_PORT, ]
 
 # Prepended to exception log messages
