@@ -45,7 +45,7 @@ ovn_conf.register_opts()
 LOG = logging.getLogger(__name__)
 
 
-class OvnProviderHelper(object):
+class OvnProviderHelper():
 
     def __init__(self):
         self.requests = queue.Queue()
@@ -66,7 +66,6 @@ class OvnProviderHelper(object):
             ovn_const.REQ_TYPE_LB_CREATE: self.lb_create,
             ovn_const.REQ_TYPE_LB_DELETE: self.lb_delete,
             ovn_const.REQ_TYPE_LB_UPDATE: self.lb_update,
-            ovn_const.REQ_TYPE_LB_FAILOVER: self.lb_failover,
             ovn_const.REQ_TYPE_LISTENER_CREATE: self.listener_create,
             ovn_const.REQ_TYPE_LISTENER_DELETE: self.listener_delete,
             ovn_const.REQ_TYPE_LISTENER_UPDATE: self.listener_update,
@@ -300,16 +299,13 @@ class OvnProviderHelper(object):
             request_handler = self._lb_request_func_maps.get(request_type)
             try:
                 if request_handler:
-                    LOG.debug("Handling request %(req)s with info %(info)s",
-                              {'req': request_type, 'info': request['info']})
                     status = request_handler(request['info'])
                     if status:
                         self._update_status_to_octavia(status)
                 self.requests.task_done()
             except driver_exceptions.UpdateStatusError as e:
-                msg = ("Error while updating the load balancer "
-                       "status: %s") % e.fault_string
-                LOG.error(msg)
+                LOG.error("Error while updating the load balancer status: %s",
+                          e.fault_string)
                 # TODO(haleyb): The resource(s) we were updating status for
                 # should be cleaned-up
             except Exception:
@@ -542,11 +538,9 @@ class OvnProviderHelper(object):
                           [lr.strip() for lr in lr_ref.split(',')]
                           if r != ovn_lr.name]
             except ValueError:
-                msg = ('The loadbalancer %(lb)s is not associated with '
-                       'the router %(router)s' %
-                       {'lb': ovn_lb.name,
-                        'router': ovn_lr.name})
-                LOG.warning(msg)
+                LOG.warning('The loadbalancer %(lb)s is not associated with '
+                            'the router %(router)s',
+                            {'lb': ovn_lb.name, 'router': ovn_lr.name})
             if lr_ref:
                 commands.append(
                     self.ovn_nbdb_api.db_set(
@@ -982,13 +976,6 @@ class OvnProviderHelper(object):
         self._execute_commands(commands)
         return status
 
-    def lb_failover(self, loadbalancer):
-        status = {
-            constants.LOADBALANCERS: [
-                {constants.ID: loadbalancer[constants.ID],
-                 constants.PROVISIONING_STATUS: constants.ACTIVE}]}
-        return status
-
     def lb_update(self, loadbalancer):
         lb_status = {constants.ID: loadbalancer[constants.ID],
                      constants.PROVISIONING_STATUS: constants.ACTIVE}
@@ -1472,31 +1459,9 @@ class OvnProviderHelper(object):
 
         external_ids[pool_key] = pool_data[pool_key]
         commands.extend(self._refresh_lb_vips(ovn_lb.uuid, external_ids))
-        subnet_id = member[constants.SUBNET_ID]
         commands.extend(
             self._update_lb_to_ls_association(
-                ovn_lb, subnet_id=subnet_id, associate=True))
-
-        # Make sure that all logical switches related to logical router
-        # are associated with the load balancer. This is needed to handle
-        # potential race that happens when lrp and lb are created at the
-        # same time.
-        neutron_client = clients.get_neutron_client()
-        try:
-            subnet = neutron_client.show_subnet(subnet_id)
-            ls_name = utils.ovn_name(subnet['subnet']['network_id'])
-            ovn_ls = self.ovn_nbdb_api.ls_get(ls_name).execute(
-                check_error=True)
-            ovn_lr = self._find_lr_of_ls(ovn_ls)
-            if ovn_lr:
-                for net in self._find_ls_for_lr(ovn_lr):
-                    commands.append(self.ovn_nbdb_api.ls_lb_add(
-                        net, ovn_lb.uuid, may_exist=True))
-        except n_exc.NotFound:
-            pass
-        except idlutils.RowNotFound:
-            pass
-
+                ovn_lb, subnet_id=member[constants.SUBNET_ID], associate=True))
         self._execute_commands(commands)
 
     def member_create(self, member):
