@@ -37,7 +37,7 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                          base.BaseLoggingTestCase):
 
     def setUp(self):
-        super(TestOvnOctaviaBase, self).setUp()
+        super().setUp()
         idl_ovn.OvnNbApiIdlImpl.ovsdb_connection = None
         # TODO(mjozefcz): Use octavia listeners to provide needed
         # sockets and modify tests in order to verify if fake
@@ -192,11 +192,10 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
 
     def _validate_loadbalancers(self, expected_lbs):
         observed_lbs = self._get_loadbalancers()
-        # NOTE (mjozefcz): assertItemsEqual works only on first level
-        # of comparison, if dicts inside dics are in diffrent
+        # NOTE (mjozefcz): assertCountEqual works only on first level
+        # of comparison, if dicts inside dicts are in different
         # order it would fail.
-        self.assertEqual(len(expected_lbs),
-                         len(observed_lbs))
+        self.assertEqual(len(expected_lbs), len(observed_lbs))
         for expected_lb in expected_lbs:
             # search for LB with same name and protocol
             found = False
@@ -308,7 +307,7 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                         calls_found.append(expected_status)
                         break
             # Validate if we found all expected calls.
-            self.assertItemsEqual(expected_statuses, calls_found)
+            self.assertCountEqual(expected_statuses, calls_found)
 
     def _wait_for_status_and_validate(self, lb_data, expected_status,
                                       check_call=True):
@@ -455,7 +454,7 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
                         'neutron:vip_port_id': vip_net_info[3],
                         'enabled': str(lb_data['model'].admin_state_up)}
         # NOTE(mjozefcz): By default we don't set protocol. We don't know if
-        # listener/pool would be TCP or UDP, so do not set it.
+        # listener/pool would be TCP, UDP or SCTP, so do not set it.
         expected_protocols = set()
 
         # Lets fetch list of L4 protocols defined for this LB.
