@@ -29,7 +29,7 @@ from ovn_octavia_provider.tests.unit import base as ovn_base
 class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
 
     def setUp(self):
-        super(TestOvnProviderDriver, self).setUp()
+        super().setUp()
         self.driver = ovn_driver.OvnProviderDriver()
         add_req_thread = mock.patch.object(ovn_helper.OvnProviderHelper,
                                            'add_request')
@@ -143,6 +143,16 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
             name='listener',
             protocol='UDP',
             protocol_port=42)
+        self.ref_listener_sctp = data_models.Listener(
+            admin_state_up=False,
+            connection_limit=5,
+            default_pool=self.ref_pool,
+            default_pool_id=self.pool_id,
+            listener_id=self.listener_id,
+            loadbalancer_id=self.loadbalancer_id,
+            name='listener',
+            protocol='SCTP',
+            protocol_port=42)
         self.fail_listener = data_models.Listener(
             admin_state_up=False,
             connection_limit=5,
@@ -389,7 +399,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                           self.driver.listener_create, self.fail_listener)
 
     def test_listener_create_multiple_protocols(self):
-        self.ovn_lb.protocol = ['tcp']
+        self.ovn_lb.protocol = ['TCP']
         info = {'id': self.ref_listener.listener_id,
                 'protocol': self.ref_listener.protocol,
                 'protocol_port': self.ref_listener.protocol_port,
@@ -405,6 +415,11 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         expected_dict = {'type': ovn_const.REQ_TYPE_LISTENER_CREATE,
                          'info': info}
         self.driver.listener_create(self.ref_listener)
+        self.ovn_lb.protocol = ['SCTP']
+        info['protocol'] = 'SCTP'
+        expected_dict = {'type': ovn_const.REQ_TYPE_LISTENER_CREATE,
+                         'info': info}
+        self.driver.listener_create(self.ref_listener)
 
     def test_listener_update(self):
         info = {'id': self.ref_listener.listener_id,
@@ -467,11 +482,9 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.mock_add_request.assert_called_once_with(expected_dict)
 
     def test_loadbalancer_failover(self):
-        info = {'id': self.ref_lb0.loadbalancer_id}
-        expected_dict = {'type': ovn_const.REQ_TYPE_LB_FAILOVER,
-                         'info': info}
-        self.driver.loadbalancer_failover(info['id'])
-        self.mock_add_request.assert_called_once_with(expected_dict)
+        self.assertRaises(exceptions.UnsupportedOptionError,
+                          self.driver.loadbalancer_failover,
+                          self.ref_lb0.loadbalancer_id)
 
     def test_pool_create_unsupported_protocol(self):
         self.ref_pool.protocol = 'HTTP'
